@@ -202,24 +202,33 @@ class SelectionList(Generic[SelectionType], OptionList):
     class SelectionToggled(SelectionMessage[MessageSelectionType]):
         """Message sent when a selection is toggled.
 
+        This is only sent when the value is *explicitly* toggled e.g.
+        via `toggle` or `toggle_all`, or via user interaction.
+        If you programmatically set a value to be selected, this message will
+        not be sent, even if it happens to be the opposite of what was
+        originally selected (i.e. setting a True to a False or vice-versa).
+
+        Since this message indicates a toggle occurring at a per-option level,
+        a message will be sent for each option that is toggled, even when a
+        bulk action is performed (e.g. via `toggle_all`).
+
         Can be handled using `on_selection_list_selection_toggled` in a subclass of
         [`SelectionList`][textual.widgets.SelectionList] or in a parent node in the DOM.
-
-        Note:
-            This message is only sent if the selection is toggled by user
-            interaction. See
-            [`SelectedChanged`][textual.widgets.SelectionList.SelectedChanged]
-            for a message sent when any change (selected or deselected,
-            either by user interaction or by API calls) is made to the
-            selected values.
         """
 
     @dataclass
     class SelectedChanged(Generic[MessageSelectionType], Message):
         """Message sent when the collection of selected values changes.
 
-        This message is sent when any change to the collection of selected
-        values takes place; either by user interaction or by API calls.
+        This is sent regardless of whether the change occurred via user interaction
+        or programmatically the the `SelectionList` API.
+
+        When a bulk change occurs, such as through `select_all` or `deselect_all`,
+        only a single `SelectedChanged` message will be sent (rather than one per
+        option).
+
+        Can be handled using `on_selection_list_selected_changed` in a subclass of
+        [`SelectionList`][textual.widgets.SelectionList] or in a parent node in the DOM.
         """
 
         selection_list: SelectionList[MessageSelectionType]
@@ -324,10 +333,10 @@ class SelectionList(Generic[SelectionType], OptionList):
         # Keep track of if anything changed.
         changed = False
 
-        # Next we run through everything and apply the change, preventing
-        # the toggled and changed messages because the caller really isn't
-        # going to be expecting a message storm from this.
-        with self.prevent(self.SelectedChanged, self.SelectionToggled):
+        # Apply the state change function to all options.
+        # We don't send a SelectedChanged for each option, and instead
+        # send a single SelectedChanged afterwards if any values change.
+        with self.prevent(self.SelectedChanged):
             for selection in self._options:
                 changed = (
                     state_change(cast(Selection[SelectionType], selection).value)
@@ -654,6 +663,11 @@ class SelectionList(Generic[SelectionType], OptionList):
         option = self.get_option_at_index(index)
         self._deselect(option.value)
         del self._values[option.value]
+        # Decrement index of options after the one we just removed.
+        self._values = {
+            option_value: option_index - 1 if option_index > index else option_index
+            for option_value, option_index in self._values.items()
+        }
         return super()._remove_option(index)
 
     def add_options(
